# Firefly.ai Python SDK
Firefly.ai python SDK 

## Documentation
https://firefly-python-sdk.readthedocs.io/en/latest/

### Example Notebook: 
https://github.com/NeuralAlgorithms/firefly-python-sdk/blob/add-example/examples/SDK_example.ipynb


## Installation:

`pip install fireflyai`

## Usage:

```
import fireflyai as firefly

firefly.authenticate(USER, PASSWORD)
```


